/** @type {import('@docusaurus/types').DocusaurusConfig} */
const gitBranch = process.env.GIT_BRANCH || 'main'

const baseUrl = process.env.DOCUSAURUS_BASE_URL || '/'

module.exports = {
  title: 'FIT-Connect',
  url: 'https://docs.fitko.de',
  baseUrl,
  onBrokenLinks: 'throw',
  onBrokenMarkdownLinks: 'throw',
  favicon: 'favicon.png',
  i18n: {
    defaultLocale: 'de',
    locales: ['de'],
  },
  themeConfig: {
    announcementBar: {
      id: 'under-construction',
      content:
        '🚧 Die Dokumentation ist aktuell noch in stetigem Wandel. Fragen, Probleme oder Feedback einfach an uns über diese <a target="_blank" href="mailto:servicedesk+fit-connect-planning-74-issue-@gitlab-incoming.fitko.net">E-Mail</a> senden.',
      backgroundColor: '#FFC819',
      textColor: '#000000',
      isCloseable: false,
    },
    colorMode: {
      disableSwitch: true,
    },
    prism: {
      additionalLanguages: ['java', 'csharp'],
    },
    navbar: {
      title: 'FIT-Connect',
      logo: {
        alt: 'FITKO',
        src: '/images/logo-fitko.svg',
      },
      items: [
        {to: '/docs', label: 'Dokumentation', position: 'left'},
        {to: '/news', label: 'News', position: 'left'},
      ],
    },
    footer: {
      style: 'light',
      copyright: `Copyright © ${new Date().getFullYear()} FITKO (Föderale IT-Kooperation) | Zum Gottschalkhof 3 | 60594 Frankfurt am Main | E-Mail: poststelle@fitko.de | https://www.fitko.de | Die FITKO ist eine Anstalt des öffentlichen Rechts. Sie wird vertreten durch die Präsidentin Frau Dr. Annette Schmidt.`,
    },
    hideableSidebar: true,
  },
  presets: [
    [
      '@docusaurus/preset-classic',
      {
        docs: {
          sidebarPath: require.resolve('./sidebar.js'),
          editUrl: ({ version, versionDocsDirPath, docPath }) =>
            `https://git.fitko.de/fit-connect/docs/-/edit/${gitBranch}/${versionDocsDirPath}/${docPath}`,
          routeBasePath: 'docs',
        },
        theme: {
          customCss: require.resolve('./src/css/custom.css'),
        },
        blog: {
          path: './news',
          routeBasePath: 'news',
          blogSidebarTitle: 'News',
          blogDescription: 'News bezüglich FIT-Connect von FITKO',
          blogTitle: 'News',
          showReadingTime: false,
          feedOptions: {
            type: 'all',
            language: 'de',
            copyright: `Copyright © ${new Date().getFullYear()} FITKO`,
          },
        },
      },
    ],
  ],
}
